@@ -1,9 +1,8 @@
 //! # sqlx-models
-//! sqlx-modes is a work in progress implementation for a sql migration management tool for applications using sqlx. 
+//! sqlx-modes is a work in progress implementation for a sql migration management tool for applications using sqlx.
 //! Beware, this is still under development, and some API's may be broken in the future. 
 //! 
 //! 
-//! 
 //! # Basic Tutorial
 //! 
 //! install the CLI by running the following command: 
@@ -13,7 +12,7 @@
 //! 
 //! Now run the following command to create an environment file with the `DATABASE_URL` variable set: 
 //! ```
-//! echo "DATABASE_URL=sqlite:/database.db" > .env
+//! echo "DATABASE_URL=sqlite://database.db" > .env
 //! ```
 //! We now can create the database running the command: 
 //! ```
@@ -133,10 +132,14 @@
 //! ```
 //! 
 //! ### default
-//! It can be used to set a default literal for a column. 
+//! It can be used to set a default for a table. 
 //! ```rust
-//!     #[default = 0]
+//!     #[default(false)] // if using sqlite use 0 or 1 instead 
 //!     is_admin: bool, 
+//!     #[default("")]
+//!     text: String, 
+//!     #[default(0)]
+//!     number: i32, 
 //! ```
 //! 
 //! ### unique
@@ -152,16 +155,23 @@
 //!     hash: i32,
 //! ```
 
-
 #[macro_use]
 mod error;
 
 mod model;
 mod prelude;
 mod scheduler;
+
+#[cfg(feature = "bincode")]
+pub use model::Binary;
+
 // mod scheduler;
 pub use sqlx_models_proc_macro::Model;
 
+
+
+
+
 #[doc(hidden)]
 pub mod private {
     use once_cell::sync::Lazy;
@@ -172,7 +182,7 @@ pub mod private {
         Table,
     };
     pub static MIGRATIONS: Lazy<Scheduler> = Lazy::new(Scheduler::new);
-    
+
     /// Do not use the types defined in this module.
     /// They are intended to be used only through the macro API.
     /// Changes in this module are not considered to be breaking changes.
